.container {
  width: 600px;
  margin: 50px auto;
}

form {
  margin-bottom: 30px;
}

.drop-area {
  margin-top: 25px;
  width: 100%;
  height: 200px;
  border: 2px solid rgb(204, 229, 255);
  border-radius: 5px;
  text-align: center;
  vertical-align: middle;
  line-height: 200px;
  color: #ddd;
  font-size: 2.5em;
}

.drop-area.drag-over {
  background: rgba(204, 229, 255, 0.3);
}

.upload-progress-item-container {
  padding: 10px 0px;
  color: #666;
}

.upload-progress-item {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  border-bottom: 0px solid #ccc;
}

.upload-progress-item .bar {
  border: 1px solid #ccc;
  height: 25px;
  width: 500px;
  border-radius: 5px
}

.upload-progress-item .bar-text {
  float: left;
  width: 100%;
  line-height: 25px;
  text-align: center;
  color: #666;
  font-size: 0.9em
}

.upload-progress-item .bar-background {
  background-color: #eee;
  height: 25px;
  border-radius: 5px
}

.upload-progress-item button {
  border-radius: 5px;
}

.error .upload-progress-item button {
  color: red;
}

.upload-progress-item-container {
  color: red;
}
